@@ -1,12 +1,14 @@
-#-*- encoding: utf-8 -*-
+# -*- encoding: utf-8 -*-
 
 '''
 Renren Client
 
 '''
+import sys
+reload(sys)
+sys.setdefaultencoding( "utf-8" )
 
 if __name__ == '__main__':
-    import sys
     sys.path.append('..')
     from snslog import SNSLog as logger
     from snsbase import SNSBase, require_authed
@@ -15,6 +17,7 @@ if __name__ == '__main__':
     import utils
     import time
     import urllib
+    import json
 else:
     from ..snslog import SNSLog as logger
     from ..snsbase import SNSBase, require_authed
@@ -24,7 +27,6 @@ else:
     import time
     import urllib
 
-
 logger.debug("%s plugged!", __file__)
 
 # Inteface URLs.
@@ -37,12 +39,17 @@ RENREN_API2_SERVER = "https://api.renren.com/v2/"
 # This error is moved back to "renren.py".
 # It's platform specific and we do not expect other
 # file to raise this error.
+
+
 class RenrenAPIError(Exception):
+
     def __init__(self, code, message):
         super(RenrenAPIError, self).__init__(message)
         self.code = code
 
+
 class RenrenFeedMessage(snstype.Message):
+
     platform = "RenrenFeed"
 
     def parse(self):
@@ -50,85 +57,84 @@ class RenrenFeedMessage(snstype.Message):
         self._parse(self.raw)
 
     def _parse(self, dct):
-        self.ID.status_id = dct['source_id']
-        self.ID.source_user_id = self.parsed.userid = str(dct['actor_id'])
-        self.parsed.username = dct['name']
-        self.parsed.time = utils.str2utc(dct['update_time'], " +08:00")
+        self.ID.status_id = dct['id']
+        self.ID.source_user_id = self.parsed.userid = str(dct['sourceUser']['id'])
+        self.parsed.username = dct['sourceUser']['name']
+        self.parsed.time = utils.str2utc(dct['time'], " +08:00")
         self.parsed.text = ""
-        self.ID.feed_type = self.parsed.feed_type = {
-            10: 'STATUS',
-            11: 'STATUS',
-            20: 'BLOG',
-            21: 'SHARE',
-            22: 'BLOG',
-            23: 'SHARE',
-            30: 'PHOTO',
-            31: 'PHOTO',
-            32: 'SHARE',
-            33: 'SHARE',
-            34: 'OTHER',
-            35: 'OTHER',
-            36: 'SHARE',
-            40: 'OTHER',
-            41: 'OTHER',
-            50: 'SHARE',
-            51: 'SHARE',
-            52: 'SHARE',
-            53: 'SHARE',
-            54: 'SHARE',
-            55: 'SHARE'
-        }[dct['feed_type']]
+        self.ID.feed_type = self.parsed.feed_type = dct['type']
+        try:
+            if self.ID.feed_type == "PUBLISH_ONE_PHOTO" or self.ID.feed_type == "PUBLISH_MORE_PHOTO":
+                self.ID.resource_id = dct["attachment"][0]["id"]
+            else:
+                self.ID.resource_id = dct["resource"]["id"]
+        except Exception, e:
+            logger.warning(str(e))
+            self.ID.resource_id = self.ID.status_id
         ORIG_USER = 'orig'
+
         if 'attachment' in dct and dct['attachment']:
             for at in dct['attachment']:
-                if 'owner_name' in at and at['owner_name']:
-                    ORIG_USER = at['owner_name']
+                if 'ownerId' in at and at['ownerId']:
+                    ORIG_USER = at['ownerId']
                     self.parsed.username_orig = ORIG_USER
         if 'message' in dct:
             self.parsed.text += dct['message']
-        if dct['feed_type'] in [21, 23, 32, 33, 36, 50, 51, 52, 53, 54, 55]:
+        if str(dct['type']) == "SHARE":
             self.parsed.text += u" //" + ORIG_USER + ":"
-        if 'title' in dct:
-            if 'message' not in dct or dct['message'] != dct['title']:
-                self.parsed.text += ' "' + dct['title'] + '" '
-        if 'description' in dct:
-            self.parsed.text += dct['description']
+        if 'title' in dct['resource'] and dct['resource']['title']:
+            if 'message' not in dct or dct['message'] != dct['resource']['title']:
+                self.parsed.text += ' "' + dct['resource']['title'] + '" '
+
+        if 'content' in dct['resource'] and dct['resource']['content']:
+            self.parsed.text += dct['resource']['content'] + "//"
+        if 'url' in dct['resource'] and dct['resource']['url']:
+            self.parsed.text += dct['resource']['url'][0:-10]
         if 'attachment' in dct and dct['attachment']:
             for at in dct['attachment']:
-                if at['media_type'] == 'photo':
+                if str(at['type']) == 'PHOTO':
+                    if ('rawImageUrl' in at and at['rawImageUrl']):
+                        data = at['rawImageUrl']
+                    else:
+                        data = at['orginalUrl']
+
                     self.parsed.attachments.append(
                         {
                             'type': 'picture',
                             'format': ['link'],
-                            #FIXME: page photo don't have raw_src
-                            'data': 'raw_src' in at and at['raw_src'] or at['src'].replace('head_', 'original_')
+                            # FIXME: page photo don't have raw_src
+                            'data': data
                         }
                     )
-                elif 'href' in at:
+                elif 'url' in at:
                     attype = 'link'
-                    if at['media_type'] in ['album', 'blog']:
-                        attype = at['media_type']
+                    if str(at['type']) in ['ALBUM', 'BLOG']:
+                        attype = str(at['type'])
                     self.parsed.attachments.append(
                         {
                             'type': attype,
                             'format': ['link'],
-                            'data': at['href']
+                            'data': at['url']
                         })
-                if 'content' in at:
-                    self.parsed.text += at['content']
-
 
 
 class RenrenStatusMessage(RenrenFeedMessage):
+
     platform = 'RenrenStatus'
 
+
 class RenrenShareMessage(RenrenFeedMessage):
+
     platform = 'RenRenShare'
 
+
 class RenrenBlogMessage(RenrenFeedMessage):
+
     platform = 'RenrenBlog'
 
+
 class RenrenPhotoMessage(RenrenFeedMessage):
+
     platform = 'RenrenPhoto'
 
 
@@ -136,12 +142,12 @@ class RenrenFeed(SNSBase):
 
     Message = RenrenFeedMessage
 
-    def __init__(self, channel = None):
+    def __init__(self, channel=None):
         super(RenrenFeed, self).__init__(channel)
         self.platform = self.__class__.__name__
 
     @staticmethod
-    def new_channel(full = False):
+    def new_channel(full=False):
         c = SNSBase.new_channel(full)
 
         c['app_key'] = ''
@@ -156,7 +162,7 @@ class RenrenFeed(SNSBase):
         return c
 
     def renren_request(self, method=None, **kwargs):
-        return self._renren_request_v1_no_sig(method, **kwargs)
+        return self._renren_request_v2(method, **kwargs)
 
     def _renren_request_v2_bearer_token(self, method=None, **kwargs):
         kwargs['access_token'] = self.token.access_token
@@ -170,7 +176,7 @@ class RenrenFeed(SNSBase):
             response = self._http_post(RENREN_API2_SERVER + method + '?' + args, {}, files=_files)
         else:
             response = self._http_get(RENREN_API2_SERVER + method, kwargs)
-        #logger.debug('response: %s', response)
+        # logger.debug('response: %s', response)
         if response == {} or 'error' in response:
             if 'error' in response:
                 logger.warning(response['error']['message'])
@@ -178,7 +184,33 @@ class RenrenFeed(SNSBase):
                 logger.warning("error")
         return response
 
+    def _renren_request_v2(self, method=None, **kwargs):
+        '''
+        A general purpose encapsulation of renren API.
+        It fills in system paramters and compute the signature.
+        Return a list on success
+        raise Exception on error
+        '''
+        kwargs['access_token'] = self.token.access_token
+        kwargs['format'] = 'json'
+        if 'file' in kwargs:
+            _files = kwargs['file']
+            del kwargs['file']
+        else:
+            _files = {}
 
+        if method == "feed/list" or method == "status/list":
+            response = self._http_get(RENREN_API2_SERVER + method, kwargs)
+        else:
+            response = self._http_post(RENREN_API2_SERVER + method, kwargs, files=_files)
+        # For like function, error will be returned if a feed is liked twice.
+        # In this case we regard it as a successful like
+        if type(response) is not list and "error" in response:
+            if response["error"]["code"] == u"invalid_request.HAS_ALREADY_LIKED":
+                return {"response": 1}
+            else:
+                raise RenrenAPIError(response["error"]["code"], response["error"]["message"])
+        return response['response']
 
     def _renren_request_v1_no_sig(self, method=None, **kwargs):
         '''
@@ -199,18 +231,15 @@ class RenrenFeed(SNSBase):
             _files = {}
         response = self._http_post(RENREN_API_SERVER, kwargs, files=_files)
 
-
         if type(response) is not list and "error_code" in response:
             logger.warning(response["error_msg"])
             raise RenrenAPIError(response["error_code"], response["error_msg"])
         return response
 
-
     def auth_first(self):
         '''
         docstring placeholder
         '''
-
         args = {"client_id": self.jsonconf.app_key,
                 "redirect_uri": self.auth_info.callback_url}
         args["response_type"] = "code"
@@ -220,7 +249,11 @@ class RenrenFeed(SNSBase):
                                   "status_update",
                                   "publish_comment",
                                   "publish_blog",
-                                  "photo_upload"])
+                                  "publish_share",
+                                  "publish_feed",
+                                  "status_update",
+                                  "photo_upload",
+                                  "operate_like"])
 
         url = RENREN_AUTHORIZATION_URI + "?" + self._urlencode(args)
         self.request_url(url)
@@ -233,14 +266,18 @@ class RenrenFeed(SNSBase):
         try:
             url = self.fetch_code()
             self.token = self._parse_code(url)
-            args = dict(client_id=self.jsonconf.app_key, redirect_uri = self.auth_info.callback_url)
+            args = dict(client_id=self.jsonconf.app_key, redirect_uri=self.auth_info.callback_url)
             args["client_secret"] = self.jsonconf.app_secret
             args["code"] = self.token.code
             args["grant_type"] = "authorization_code"
             self.token.update(self._http_get(RENREN_ACCESS_TOKEN_URI, args))
-            self.token.expires_in = self.token.expires_in + self.time()
+            if hasattr(self.token, "expires_in"):
+                self.token.expires_in = self.token.expires_in + self.time()
+            else:
+                self.token.expires_in = self.time() + 60 * 60 * 7 * 24
+            # In case that no "expires_in" property is returned.
         except Exception, e:
-            logger.warning("Auth second fail. Catch exception: %s", e)
+            logger.warning("Auth second fail. Catch exception: %s", (e))
             self.token = None
 
     def auth(self):
@@ -265,13 +302,16 @@ class RenrenFeed(SNSBase):
 
     @require_authed
     def home_timeline(self, count=20, **kwargs):
-        #FIXME: automatic paging for count > 100
-        ttype='10,11,20,21,22,23,30,31,32,33,34,35,36,40,41,50,51,52,53,54,55'
+        # FIXME: automatic paging for count > 100
+        # BUG: It seems that ttype has no influence
+        # on the returned value of renren_request()
+        ttype = 'ALL'
         if 'type' in kwargs:
             ttype = kwargs['type']
+
         try:
             jsonlist = self.renren_request(
-                method="feed.get",
+                method="feed/list",
                 page=1,
                 count=count,
                 type=ttype,
@@ -279,14 +319,13 @@ class RenrenFeed(SNSBase):
         except RenrenAPIError, e:
             logger.warning("RenrenAPIError, %s", e)
             return snstype.MessageList()
-
         statuslist = snstype.MessageList()
         for j in jsonlist:
             try:
                 statuslist.append(self.Message(
                     j,
-                    platform = self.jsonconf['platform'],
-                    channel = self.jsonconf['channel_name']
+                    platform=self.jsonconf['platform'],
+                    channel=self.jsonconf['channel_name']
                 ))
             except Exception, e:
                 logger.warning("Catch exception: %s", e)
@@ -297,8 +336,8 @@ class RenrenFeed(SNSBase):
     def _update_status(self, text):
         try:
             self.renren_request(
-                method='status.set',
-                status = text
+                method='status/put',
+                content=text
             )
             return BooleanWrappedData(True)
         except:
@@ -306,11 +345,10 @@ class RenrenFeed(SNSBase):
                 'errors': ['PLATFORM_'],
             })
 
-
     def _update_blog(self, text, title):
         try:
             self.renren_request(
-                method='blog.addBlog',
+                method='blog/put',
                 title=title,
                 content=text
             )
@@ -320,27 +358,25 @@ class RenrenFeed(SNSBase):
                 'errors': ['PLATFORM_'],
             })
 
-
     def _update_share_link(self, text, link):
         try:
             self.renren_request(
-                method='share.share',
-                type='6',
+                method='share/url/put',
                 url=link,
                 comment=text
             )
             return BooleanWrappedData(True)
         except:
-            return    BooleanWrappedData(False, {
+            return BooleanWrappedData(False, {
                 'errors': ['PLATFORM_']
             })
 
     def _update_photo(self, text, pic):
         try:
             self.renren_request(
-                method='photos.upload',
-                caption=text,
-                _files={'upload': ('%d.jpg' % int(time.time()), pic)}
+                method='photo/upload',
+                description=text,
+                file={'upload': ('%d.jpg' % int(time.time()), pic)}
             )
             return BooleanWrappedData(True)
         except:
@@ -353,13 +389,13 @@ class RenrenFeed(SNSBase):
 
     @require_authed
     def update(self, text, **kwargs):
-        coder= int(''.join(map(lambda t: str(int(t)),
+        coder = int(''.join(map(lambda t: str(int(t)),
                                [
                                    'title' in kwargs,
                                    'link' in kwargs,
                                    'pic' in kwargs
                                ][::-1])
-                           ))
+                    ))
         try:
             update_what = {
                 0: self._update_status,
@@ -369,89 +405,35 @@ class RenrenFeed(SNSBase):
             }[coder]
         except:
             return BooleanWrappedData(False, {
-                'errors' : ['SNSAPI_NOT_SUPPORTED'],
+                'errors': ['SNSAPI_NOT_SUPPORTED'],
             })
         return update_what(text, **kwargs)
 
     @require_authed
     def reply(self, statusId, text):
-        #NOTE: you can mix API1 and API2.
-        #NOTE: API2 is more better on comment
         res = None
+        flag = False
         try:
-            if statusId.feed_type == 'STATUS':
+            # The order in the bracket is important since there
+            # exists "SHARE_XXXX" type. In order to figure out
+            # the actual type, SHARE must be put in the first position.
+            for msg_type in ["SHARE", "BLOG", "PHOTO", "ALBUM", "STATUS", "VIDEO"]:
+                if msg_type in statusId.feed_type:
+                    flag = True
+                    break
+            if flag:
                 res = self.renren_request(
-                    method='status.addComment',
-                    status_id=statusId.status_id,
-                    owner_id=statusId.source_user_id,
-                    content=text
-                )
-            elif statusId.feed_type == 'SHARE':
-                res = self.renren_request(
-                    method='share.addComment',
-                    share_id=statusId.status_id,
-                    user_id=statusId.source_user_id,
-                    content=text
-                )
-            elif statusId.feed_type == 'BLOG':
-                res = self.renren_request(
-                    method='blog.addComment',
-                    id=statusId.status_id,
-                    #FIXME: page_id, uid
-                    uid=statusId.source_user_id,
-                    content=text
-                )
-            elif statusId.feed_type == 'PHOTO':
-                res = self.renren_request(
-                    method='photos.addComment',
-                    uid=statusId.source_user_id,
+                    method="comment/put",
                     content=text,
-                    #FIXME: aid, pid
-                    pid=statusId.status_id
+                    commentType=msg_type,
+                    entryOwnerId=statusId.source_user_id,
+                    entryId=statusId.resource_id
                 )
             else:
                 return BooleanWrappedData(False, {
-                    'errors' : ['SNSAPI_NOT_SUPPORTED'],
+                    'errors': ['SNSAPI_NOT_SUPPORTED'],
                 })
-        except:
-            return BooleanWrappedData(False, {
-                'errors': ['PLATFORM_'],
-            })
-        if res:
-            return BooleanWrappedData(True)
-        else:
-            return BooleanWrappedData(False, {
-                'errors' : ['PLATFORM_'],
-            })
-
-    @require_authed
-    def forward(self, message, text):
-        res = None
-        try:
-            if message.ID.feed_type == 'STATUS':
-                res = self.renren_request(
-                    method='status.forward',
-                    status=text,
-                    forward_id=message.ID.status_id,
-                    forward_owner=message.ID.source_user_id,
-                )
-            elif message.ID.feed_type != 'OTHER':
-                res = self.renren_request(
-                    method='share.share',
-                    type=str({
-                        'BLOG': 1,
-                        'PHOTO': 2,
-                        'SHARE': 20
-                    }[message.parsed.feed_type]),
-                    ugc_id=message.ID.status_id,
-                    user_id=message.ID.source_user_id,
-                    comment=text
-                )
-            else:
-                return BooleanWrappedData(False, {
-                    'errors' : ['SNSAPI_NOT_SUPPORTED'],
-                })
-        except Exception as e:
+        except Exception, e:
             logger.warning('Catch exception: %s', e)
             return BooleanWrappedData(False, {
                 'errors': ['PLATFORM_'],
@@ -460,11 +442,117 @@ class RenrenFeed(SNSBase):
             return BooleanWrappedData(True)
         else:
             return BooleanWrappedData(False, {
-                'errors' : ['PLATFORM_'],
+                'errors': ['PLATFORM_'],
             })
 
+    @require_authed
+    def forward(self, message, text):
+        res = None
+        if not message.platform == self.platform:
+            return super(RenrenFeed, self).forward(message, text)
+        else:
+            try:
+                if message.ID.feed_type == 'UPDATE_STATUS':
+                    res = self.renren_request(
+                        method='status/share',
+                        content=text,
+                        statusId=message.ID.resource_id,
+                        ownerId=message.ID.source_user_id,
+                    )
+
+                elif message.ID.feed_type != 'OTHER':
+                    for msg_type in ["SHARE", "BLOG", "PHOTO", "ALBUM", "VIDEO"]:
+                        if msg_type in message.ID.feed_type:
+                            break
+                    # The order in the bracket is important since there
+                    # exists "SHARE_XXXX" type. In order to figure out
+                    # the actual type, SHARE must be put in the first position.
+                    res = self.renren_request(
+                        method='share/ugc/put',
+                        ugcType="TYPE_" + msg_type,
+                        ugcId=message.ID.resource_id,
+                        # Here message.ID.resource_id is the proper id
+                        # for forwarding these messages instead of message.ID.status_id
+                        ugcOwnerId=message.ID.source_user_id,
+                        comment=text
+                    )
+                else:
+                    return BooleanWrappedData(False, {
+                        'errors': ['SNSAPI_NOT_SUPPORTED'],
+                    })
+            except Exception as e:
+                logger.warning('Catch exception: %s', e)
+                return BooleanWrappedData(False, {
+                    'errors': ['PLATFORM_'],
+                })
+        if res:
+            return BooleanWrappedData(True)
+        else:
+            return BooleanWrappedData(False, {
+                'errors': ['PLATFORM_'],
+            })
+    
+    @require_authed
+    def like(self, message):
+        res = None
+        flag = False
+        try:
+            # The order in the bracket is important since there
+            # exists "SHARE_XXXX" type. In order to figure out
+            # the actual type, SHARE must be put in the first position.
+            for msg_type in ["SHARE", "BLOG", "PHOTO", "ALBUM", "STATUS", "VIDEO"]:
+                if msg_type in message.ID.feed_type:
+                    flag = True
+                    break
+            if flag:
+                res = self.renren_request(
+                    method="like/ugc/put",
+                    ugcOwnerId=message.ID.source_user_id,
+                    likeUGCType="TYPE_" + msg_type,
+                    ugcId=message.ID.resource_id
+                )
+            else:
+                return False
+        except Exception as e:
+            logger.warning('Catch exception: %s', e)
+            return False
+        if res:
+            return True
+        else:
+            return False
+
+    @require_authed
+    def unlike(self, message):
+        res = None
+        flag = False
+        try:
+            # The order in the bracket is important since there
+            # exists "SHARE_XXXX" type. In order to figure out
+            # the actual type, SHARE must be put in the first position.
+            for msg_type in ["SHARE", "BLOG", "PHOTO", "ALBUM", "STATUS", "VIDEO"]:
+                if msg_type in message.ID.feed_type:
+                    flag = True
+                    break
+            if flag:
+                res = self.renren_request(
+                    method="like/ugc/remove",
+                    ugcOwnerId=message.ID.source_user_id,
+                    likeUGCType="TYPE_" + msg_type,
+                    ugcId=message.ID.resource_id
+                )
+            else:
+                return False
+        except Exception as e:
+            logger.warning('Catch exception: %s', type(e))
+            return False
+        if res:
+            return True
+        else:
+            return False
+
 
 class RenrenStatus(RenrenFeed):
+
     Message = RenrenStatusMessage
 
     def __init__(self, channel=None):
@@ -478,7 +566,7 @@ class RenrenStatus(RenrenFeed):
 
     @require_authed
     def home_timeline(self, count=20):
-        return RenrenFeed.home_timeline(self, count, type='10,11')
+        return RenrenFeed.home_timeline(self, count, type='UPDATE_STATUS')
 
     @require_authed
     def update(self, text):
@@ -486,6 +574,7 @@ class RenrenStatus(RenrenFeed):
 
 
 class RenrenBlog(RenrenFeed):
+
     Message = RenrenBlogMessage
 
     def __init__(self, channel=None):
@@ -499,15 +588,17 @@ class RenrenBlog(RenrenFeed):
 
     @require_authed
     def home_timeline(self, count=20):
-        return RenrenFeed.home_timeline(self, count, type='20,22')
+        return RenrenFeed.home_timeline(self, count, type='PUBLISH_BLOG,SHARE_BLOG')
 
     @require_authed
     def update(self, text, title=None):
         if not title:
             title = text.split('\n')[0]
-            return RenrenFeed._update_blog(self, text, title)
+        return RenrenFeed._update_blog(self, text, title)
+
 
 class RenrenPhoto(RenrenFeed):
+
     Message = RenrenPhotoMessage
 
     def __init__(self, channel=None):
@@ -521,13 +612,15 @@ class RenrenPhoto(RenrenFeed):
 
     @require_authed
     def home_timeline(self, count=20):
-        return RenrenFeed.home_timeline(self, count, type='30,31')
+        return RenrenFeed.home_timeline(self, count, type='PUBLISH_ONE_PHOTO,PUBLISH_MORE_PHOTO')
 
     @require_authed
     def update(self, text, pic=None):
         return self._update_photo(text, pic)
 
+
 class RenrenShare(RenrenFeed):
+
     Message = RenrenShareMessage
 
     def __init__(self, channel=None):
@@ -541,7 +634,7 @@ class RenrenShare(RenrenFeed):
 
     @require_authed
     def home_timeline(self, count=20):
-        return RenrenFeed.home_timeline(self, count, type='21,23,32,33,36,50,51,52,53,54,55')
+        return RenrenFeed.home_timeline(self, count, type='SHARE_BLOG,SHARE_LINK,SHARE_PHOTO,SHARE_ALBUM,SHARE_VIDEO')
 
     @require_authed
     def update(self, text, link=None):
@@ -551,6 +644,7 @@ class RenrenShare(RenrenFeed):
 
 
 class RenrenStatusDirectMessage(snstype.Message):
+
     platform = "RenrenStatusDirect"
 
     def parse(self):
@@ -558,16 +652,18 @@ class RenrenStatusDirectMessage(snstype.Message):
         self._parse(self.raw)
 
     def _parse(self, dct):
-        self.ID.status_id = dct['status_id']
-        self.ID.source_user_id = dct['uid']
+        self.ID.status_id = dct['id']
+        self.ID.source_user_id = dct['ownerId']
         self.ID.feed_type = 'STATUS'
 
-        self.parsed.userid = str(dct['uid'])
+        self.parsed.userid = str(dct['ownerId'])
         self.parsed.username = dct['name']
-        self.parsed.time = utils.str2utc(dct['time'], " +08:00")
-        self.parsed.text = dct['message']
+        self.parsed.time = utils.str2utc(dct['createTime'], " +08:00")
+        self.parsed.text = dct['content']
+
 
 class RenrenStatusDirect(RenrenFeed):
+
     Message = RenrenStatusDirectMessage
 
     def __init__(self, channel=None):
@@ -592,10 +688,10 @@ class RenrenStatusDirect(RenrenFeed):
     def _get_user_status_list(self, count, userid, username):
         try:
             jsonlist = self.renren_request(
-                method="status.gets",
-                page=1,
-                count=count,
-                uid = userid,
+                method="status/list",
+                pageNumberint=1,
+                pageSize=count,
+                ownerId=userid,
             )
         except RenrenAPIError, e:
             logger.warning("RenrenAPIError, %s", e)
@@ -607,8 +703,8 @@ class RenrenStatusDirect(RenrenFeed):
                 j['name'] = username
                 statuslist.append(self.Message(
                     j,
-                    platform = self.jsonconf['platform'],
-                    channel = self.jsonconf['channel_name']
+                    platform=self.jsonconf['platform'],
+                    channel=self.jsonconf['channel_name']
                 ))
             except Exception, e:
                 logger.warning("Catch exception: %s", e)
